@@ -1,4 +1,4 @@
-# $Id: /local/Mango/trunk/t/lib/Mango/Test/Catalyst/Log.pm 309 2007-05-29T15:19:54.893692Z claco  $
+# $Id: /local/Mango/trunk/t/lib/Mango/Test/Catalyst/Log.pm 1828 2007-08-11T00:17:05.755369Z claco  $
 package Mango::Test::Catalyst::Log;
 use strict;
 use warnings;
@@ -20,4 +20,8 @@ sub error {
     die shift;
 };
 
-1;
\ No newline at end of file
+sub warn {
+    warn @_;
+};
+
+1;
